package com.unissoft.config;

import org.eclipse.paho.client.mqttv3.MqttConnectOptions;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.integration.mqtt.core.DefaultMqttPahoClientFactory;
import org.springframework.integration.mqtt.core.MqttPahoClientFactory;

/**
 * @author qingsong.han
 * @description: mqtt 基础配置
 * @create 2023-02-14 14:04
 */
@Configuration
public class MqttBaseConfig {

    /**
     * 出站-生产者
     */
    public static final String CHANNEL_NAME_OUT = "mqttOutputChannel";

    /**
     * 入站-消费者
     */
    static final String CHANNEL_NAME_IN = "mqttInputChannel";

    @Value("${mqtt.serverURIs}")
    private String mqttServerURIs;
    @Value("${mqtt.username}")
    private String mqttUserName;
    @Value("${mqtt.password}")
    private String mqttPwd;
    @Value("${mqtt.keepAliveInterval}")
    private Integer keepAliveInterval;
    @Value("${mqtt.cleanSession}")
    private Boolean cleanSession;

    /**
     * 创建设置MQTT Broker连接属性,如果使用SSL验证,也在这里设置(构造一个默认的mqtt客户端操作bean)
     *
     * @return MqttPahoClientFactory
     */
    @Bean
    public MqttPahoClientFactory factory() {
        DefaultMqttPahoClientFactory factory = new DefaultMqttPahoClientFactory();
        MqttConnectOptions options = new MqttConnectOptions();
        //如果配置了用户密码这里需要对应设置
        options.setUserName(mqttUserName);
        options.setPassword(mqttPwd.toCharArray());
        String[] array = mqttServerURIs.split(",");
        options.setServerURIs(array);
        // 设为false，客户端掉线后 服务器端不会清除session，当重连后可以接收之前订阅主题的消息。当客户端上线后会接受到它离线的这段时间的消息
        options.setCleanSession(cleanSession);
        // 设置会话心跳时间 单位为秒
        options.setKeepAliveInterval(keepAliveInterval);
        factory.setConnectionOptions(options);
        return factory;
    }

}
